@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
-from __future__ import with_statement
 
 ##--------------------------------------#######
 #                   Points                    #
@@ -26,14 +24,12 @@ from __future__ import with_statement
 from random import uniform, normalvariate
 from math import cos, sin, pi
 
-from numpy import ndarray
-
 from sympy import cos as scos, sin as ssin
 
 from .objet import Objet_avec_coordonnees, Ref, Argument, Objet, Arguments, \
                    contexte, Objet_avec_coordonnees_modifiables, issympy
 from .routines import angle_vectoriel, vect, carre_distance, produit_scalaire, \
-                      distance
+                      distance, confondus, distincts
 
 from .. import param
 
@@ -46,7 +42,7 @@ from .. import param
 
 
 class Point_generique(Objet_avec_coordonnees):
-    u"""Un point générique.
+    """Un point générique.
 
     Usage interne : la classe mère pour tous les types de points (libres, barycentres, intersection...)."""
 
@@ -126,31 +122,28 @@ class Point_generique(Objet_avec_coordonnees):
         from .vecteurs import Vecteur_generique
         if isinstance(y, Vecteur_generique):
             return Point_final(self, [y])
-        raise TypeError, "vecteur attendu"
+        raise TypeError("vecteur attendu")
 
+    # <A SUPPRIMER note="Accepter la syntaxe A->B dans l'interprète par contre.">
     # A>B est un alias de Vecteur(A,B) - attention aux parentheses pour 2*(A>B) !
     # A ne pas utiliser en interne (code peu lisible)
     def __gt__(self, point2):
         from .vecteurs import Vecteur
         return Vecteur(self, point2)
+    # </A SUPPRIMER>
 
 
     def _distance_inf(self, x, y, d):
         x0, y0 = self._pixel()
         return (x - x0)**2 + (y - y0)**2 < d**2
 
+    def confondu(self, *points):
+        return all(confondus(self, M) for M in points)
 
-    def __eq__(self, y):
-        if self.existe:
-            if  isinstance(y, Point_generique) and y.existe:
-                return abs(self.x - y.x) < contexte['tolerance'] and abs(self.y - y.y) < contexte['tolerance']
-            elif isinstance(y, (list, tuple, ndarray)) and len(y) == 2:
-                return abs(self.x - y[0]) < contexte['tolerance'] and abs(self.y - y[1]) < contexte['tolerance']
-        return False
-
-    def __ne__(self, y):
-        return not (self == y)
+    egale = egal = confondu
 
+    def distinct(self, *points):
+        return all(distincts(self, M) for M in points)
 
     def relier_axe_x(self):
         if self.feuille is not None:
@@ -186,12 +179,12 @@ class Point_generique(Objet_avec_coordonnees):
     def _convertir(objet):
         if hasattr(objet, "__iter__"):
             return Point(*objet)
-        raise TypeError, "'" + str(type(objet)) + "' object is not iterable"
+        raise TypeError("'" + str(type(objet)) + "' object is not iterable")
 
 
 
 class Point(Objet_avec_coordonnees_modifiables, Point_generique):
-    u"""Un point libre.
+    """Un point libre.
 
     >>> from wxgeometrie.geolib import Point
     >>> A = Point(7, 3)
@@ -221,7 +214,7 @@ class Point(Objet_avec_coordonnees_modifiables, Point_generique):
             # Par contre, si l'objet sélectionné est un texte, il n'y a pas de
             # glisseur correspondant, donc on ne tient pas compte de l'objet
             # sélectionné, et on construit simplement un point 'normal'.
-            for type_objet, type_glisseur in cls._glisseurs.iteritems():
+            for type_objet, type_glisseur in cls._glisseurs.items():
                 if isinstance(args[0], getattr(geolib, type_objet)):
                     return getattr(geolib, type_glisseur)(*args, **kw)
         return object.__new__(cls)
@@ -259,12 +252,12 @@ class Point(Objet_avec_coordonnees_modifiables, Point_generique):
             self.x = objet.x
             self.y = objet.y
         else:
-            raise TypeError, "L'objet n'est pas un point."
+            raise TypeError("L'objet n'est pas un point.")
 
 
 
 class Point_pondere(Objet):
-    u"""Un point pondéré.
+    """Un point pondéré.
 
     Usage interne : les points pondérés sont utilisés dans la définition des barycentres."""
 
@@ -277,7 +270,7 @@ class Point_pondere(Objet):
             return Point_pondere(objet)
         elif hasattr(objet, "__iter__"):
             return Point_pondere(*objet)
-        raise TypeError, "'" + str(type(objet)) + "' object is not iterable"
+        raise TypeError("'" + str(type(objet)) + "' object is not iterable")
 
     def __init__(self, point = None, coefficient = None, **styles):
 ##        if coefficient is None:
@@ -291,7 +284,7 @@ class Point_pondere(Objet):
 
 
 class Barycentre(Point_generique):
-    u"""Un barycentre.
+    """Un barycentre.
 
     Un barycentre de n points."""
 
@@ -306,7 +299,7 @@ class Barycentre(Point_generique):
 
 
     def _get_coordonnees(self):
-        u"Coordonnées du barycentre en fonction de celles des points."
+        "Coordonnées du barycentre en fonction de celles des points."
         total = self._cache.get('somme_coeff', self.__somme_coeffs)
         return sum(coeff*point.x for point, coeff in self.__points_ponderes)/total, \
                     sum(coeff*point.y for point, coeff in self.__points_ponderes)/total
@@ -319,13 +312,13 @@ class Barycentre(Point_generique):
 
 
     def __somme_coeffs(self):
-        return sum(point_pondere._Point_pondere__coefficient.valeur for point_pondere in self.__points_ponderes)
+        return sum(point_pondere._Point_pondere__coefficient for point_pondere in self.__points_ponderes)
 
 
 
 
 class Milieu(Barycentre):
-    u"""Un milieu.
+    """Un milieu.
 
     Le milieu de 2 points"""
 
@@ -347,7 +340,7 @@ class Milieu(Barycentre):
 
 
 class Point_final(Point_generique):
-    u"""Un point défini par une relation vectorielle.
+    """Un point défini par une relation vectorielle.
 
     Point défini par une relation vectorielle.
                               ->      ->     ->
@@ -393,7 +386,7 @@ class Point_final(Point_generique):
 
 
 class Point_translation(Point_generique):
-    u"""Une image d'un point par translation."""
+    """Une image d'un point par translation."""
 
     point = __point = Argument("Point_generique")
     translation = __translation = Argument("Translation")
@@ -410,7 +403,7 @@ class Point_translation(Point_generique):
 
 
 class Point_rotation(Point_generique):
-    u"""Une image d'un point par rotation.
+    """Une image d'un point par rotation.
 
     Point construit à partir d'un autre via une rotation d'angle et de centre donné."""
 
@@ -446,7 +439,7 @@ class Point_rotation(Point_generique):
 
 
 class Point_homothetie(Point_generique):
-    u"""Une image d'un point par homothétie.
+    """Une image d'un point par homothétie.
 
     Point construit à partir d'un autre via une homothétie de rapport et de centre donné."""
 
@@ -470,7 +463,7 @@ class Point_homothetie(Point_generique):
 
 
 class Point_reflexion(Point_generique):
-    u"""Une image d'un point par réflexion.
+    """Une image d'un point par réflexion.
 
     Point construit à partir d'un autre via une symétrie d'axe donné."""
 
@@ -503,7 +496,7 @@ class Point_reflexion(Point_generique):
 
 
 class Projete_generique(Point_generique):
-    u"""Un projeté générique.
+    """Un projeté générique.
 
     Classe mère des différents types de projetés orthogonaux (sur droite, sur cercle ou sur segment)."""
 
@@ -523,7 +516,7 @@ class Projete_generique(Point_generique):
 
 
 class Projete_droite(Projete_generique):
-    u"""Un projeté orthogonal sur une droite.
+    """Un projeté orthogonal sur une droite.
 
     Projeté orthogonal d'un point sur une droite."""
 
@@ -555,7 +548,7 @@ class Projete_droite(Projete_generique):
 
 
 class Projete_cercle(Projete_generique):
-    u"""Un projeté orthogonal sur un cercle.
+    """Un projeté orthogonal sur un cercle.
 
     Projeté orthogonal d'un point sur un cercle."""
 
@@ -589,7 +582,7 @@ class Projete_cercle(Projete_generique):
 
 
 class Projete_arc_cercle(Projete_generique):
-    u"""Un projeté orthogonal sur un arc de cercle.
+    """Un projeté orthogonal sur un arc de cercle.
 
     Projeté orthogonal d'un point sur un arc de cercle."""
 
@@ -639,7 +632,7 @@ class Projete_arc_cercle(Projete_generique):
 
 
 class Projete_segment(Projete_generique):
-    u"""Un projeté orthogonal sur un segment.
+    """Un projeté orthogonal sur un segment.
 
     Projeté orthogonal d'un point sur un segment."""
 
@@ -672,7 +665,7 @@ class Projete_segment(Projete_generique):
 
 
 class Projete_demidroite(Projete_generique):
-    u"""Un projeté orthogonal sur une demi-droite.
+    """Un projeté orthogonal sur une demi-droite.
 
     Projeté orthogonal d'un point sur une demi-droite."""
 
@@ -703,7 +696,7 @@ class Projete_demidroite(Projete_generique):
 
 
 class Centre_polygone_generique(Point_generique):
-    u"""Un centre d'un triangle.
+    """Un centre d'un triangle.
 
     Classe mère des différents centres d'un triangle."""
 
@@ -718,7 +711,7 @@ class Centre_polygone_generique(Point_generique):
 
 
 class Centre_gravite(Centre_polygone_generique):
-    u"""Un centre de gravité.
+    """Un centre de gravité.
 
     Centre de gravité d'un polygone (l'intersection des médianes dans le cas d'un triangle)."""
 
@@ -749,7 +742,7 @@ class Centre_gravite(Centre_polygone_generique):
 
 
 class Orthocentre(Centre_polygone_generique):
-    u"""Un orthocentre.
+    """Un orthocentre.
 
     Orthocentre d'un triangle (intersection des hauteurs)."""
 
@@ -772,7 +765,7 @@ class Orthocentre(Centre_polygone_generique):
 
 
 class Centre_cercle_circonscrit(Centre_polygone_generique):
-    u"""Un centre du cercle circonscrit.
+    """Un centre du cercle circonscrit.
 
     Centre du cercle circonscrit d'un triangle (intersection des médiatrices)."""
 
@@ -795,7 +788,7 @@ class Centre_cercle_circonscrit(Centre_polygone_generique):
 
 
 class Centre_cercle_inscrit(Centre_polygone_generique):
-    u"""Un centre du cercle inscrit.
+    """Un centre du cercle inscrit.
 
     Centre du cercle inscrit d'un triangle (intersection des bissectrices)."""
 
@@ -818,7 +811,7 @@ class Centre_cercle_inscrit(Centre_polygone_generique):
 
 
 class Centre(Point_generique):
-    u"""Un centre de cercle."""
+    """Un centre de cercle."""
 
     _prefixe_nom = "O"
 
@@ -847,7 +840,7 @@ class Centre(Point_generique):
 
 
 class Point_equidistant(Point_generique):
-    u"""Point équidistant de 3 points.
+    """Point équidistant de 3 points.
 
     Utilisé surtout pour un usage interne, le calcul des coordonnées est plus rapide qu'en passant par les médiatrices."""
 
@@ -905,7 +898,7 @@ class Point_equidistant(Point_generique):
 
 
 class Glisseur_generique(Point_generique):
-    u"""Un glisseur générique.
+    """Un glisseur générique.
 
     Classe mère des différents types de glisseurs"""
 
@@ -930,7 +923,7 @@ class Glisseur_generique(Point_generique):
 
 
 class Glisseur_vecteur(Glisseur_generique):
-    u"""Un glisseur sur vecteur."""
+    """Un glisseur sur vecteur."""
 
     vecteur = __vecteur = Argument("Vecteur")
     parametre = k = __k = Argument("Variable_generique", None, lambda obj, value: max(min(value, 1), 0))
@@ -955,7 +948,7 @@ class Glisseur_vecteur(Glisseur_generique):
 
 
 class Glisseur_ligne_generique(Glisseur_generique):
-    u"""Un glisseur générique sur ligne.
+    """Un glisseur générique sur ligne.
 
     Classe mère des différents types de glisseurs sur ligne (ie. droite, segment, demi-droite)"""
 
@@ -978,7 +971,7 @@ class Glisseur_ligne_generique(Glisseur_generique):
 
 
 class Glisseur_droite(Glisseur_ligne_generique):
-    u"""Un point sur une droite.
+    """Un point sur une droite.
 
     Point pouvant 'glisser' sur une droite. k est un coefficient barycentrique.
     Si A et B sont les deux points de référence de la droite, k le coefficient,
@@ -1003,7 +996,7 @@ class Glisseur_droite(Glisseur_ligne_generique):
 
 
 class Glisseur_segment(Glisseur_ligne_generique):
-    u"""Un point sur un segment.
+    """Un point sur un segment.
 
     Point pouvant 'glisser' sur un segment. k est un coefficient barycentrique.
     Si A et B sont les deux points de référence de la droite, k le coefficient,
@@ -1028,7 +1021,7 @@ class Glisseur_segment(Glisseur_ligne_generique):
 
 
 class Glisseur_demidroite(Glisseur_ligne_generique):
-    u"""Un point sur une demi-droite.
+    """Un point sur une demi-droite.
 
     Point pouvant 'glisser' sur un segment. k est un coefficient barycentrique.
     Si A et B sont les deux points de référence de la droite, k le coefficient,
@@ -1053,7 +1046,7 @@ class Glisseur_demidroite(Glisseur_ligne_generique):
 
 
 class Glisseur_cercle(Glisseur_generique):
-    u"""Un point sur un cercle.
+    """Un point sur un cercle.
 
     Point pouvant 'glisser' sur un cercle. k est un angle.
     Si O et r sont les centres et rayons du cercle, k l'angle,
@@ -1084,7 +1077,7 @@ class Glisseur_cercle(Glisseur_generique):
     def _conversion_coordonnees_parametre(self, x, y):
         O = self.__cercle.centre
         M = (x, y)
-        if O != M:
+        if O.distinct(M):
             return angle_vectoriel((1, 0), vect(O, M))
         else:
             return  0
@@ -1093,7 +1086,7 @@ class Glisseur_cercle(Glisseur_generique):
 
 
 class Glisseur_arc_cercle(Glisseur_generique):
-    u"""Un point sur un arc de cercle.
+    """Un point sur un arc de cercle.
 
     Point pouvant 'glisser' sur un cercle. k est un angle.
     Si O et r sont les centres et rayons de l'arc, k un coefficient compris entre 0 et 1,
@@ -1130,7 +1123,7 @@ class Glisseur_arc_cercle(Glisseur_generique):
     def _conversion_coordonnees_parametre(self, x, y):
         M = (x, y)
         O = self.__arc.centre;
-        if O != M:
+        if O.distinct(M):
             a, b = self.__arc._intervalle()
             c = angle_vectoriel((1, 0), vect(O, M))
             while c < a:
@@ -1154,7 +1147,7 @@ class Glisseur_arc_cercle(Glisseur_generique):
 
 
 class Glisseur_courbe(Glisseur_generique):
-    u"""Un point sur une courbe.
+    """Un point sur une courbe.
 
     Point pouvant 'glisser' sur une courbe d'interpolation ou de fonction::
 
@@ -1170,7 +1163,7 @@ class Glisseur_courbe(Glisseur_generique):
     """
 
     def _set_x(self, val):
-        u"L'abscisse du glisseur est entre les abscisses extrêmes de la courbe."
+        "L'abscisse du glisseur est entre les abscisses extrêmes de la courbe."
         return max(min(val, self.courbe.xmax), self.courbe.xmin)
 
     courbe = __courbe = Argument("Interpolation_polynomiale_par_morceaux, Courbe")
@@ -1193,13 +1186,13 @@ class Glisseur_courbe(Glisseur_generique):
 
 
 class Point_interpolation(Point_generique):
-    u"""Un point avec une pente associée.
+    """Un point avec une pente associée.
 
     Usage interne : les points d'interpolation sont utilisés pour la construction
     des courbes d'interpolation."""
 
     point = __point = Argument("Point_generique", defaut=Point)
-    derivee = __derivee = Argument("Variable_generique,NoneType", defaut=None)
+    derivee = __derivee = Argument("Variable_generique,None", defaut=None)
 
     @staticmethod
     def _convertir(objet):
@@ -1207,7 +1200,7 @@ class Point_interpolation(Point_generique):
             return Point_interpolation(objet)
         elif hasattr(objet, "__iter__"):
             return Point_interpolation(*objet)
-        raise TypeError, "'" + str(type(objet)) + "' object is not iterable"
+        raise TypeError("'" + str(type(objet)) + "' object is not iterable")
 
     def __init__(self, point=None, derivee=None, **styles):
         self.__point = point = Ref(point)
@@ -1222,7 +1215,7 @@ class Point_interpolation(Point_generique):
 
 
 class Nuage_generique(Objet):
-    u"""Un nuage de points generique.
+    """Un nuage de points generique.
 
     Usage interne : la classe mère de tous les nuages de points."""
 
@@ -1248,7 +1241,7 @@ class Nuage_generique(Objet):
 
 
 class Nuage(Nuage_generique):
-    u"""Un nuage de points.
+    """Un nuage de points.
 
     Le nuage est défini par la donnée de ses points.
     """
@@ -1273,7 +1266,7 @@ class Nuage(Nuage_generique):
 
 
 class NuageFonction(Nuage_generique):
-    u"""Un nuage de points de coordonnées (x; f(x)).
+    """Un nuage de points de coordonnées (x; f(x)).
 
     Le nuage est défini par la donnée de la fonction f,
     et d'une liste d'abscisses.
