@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 
 from pytest import XFAIL
 
@@ -11,32 +10,39 @@ from wxgeometrie.mathlib.solvers import resoudre, positif, ensemble_definition
 
 #VERBOSE = False
 
-from tools.testlib import assertEqual
+from tools.testlib import assertEqual, assertEqualAny
 
 #~ def assertEqual(x, y):
     #~ if x != y:
         #~ print "ERREUR:", repr(x), "!=", repr(y)
     #~ assert(x == y)
 
+def _red(s):
+    return '\033[0;31m' + s + '\033[0m'
+
 def assert_resoudre(x, y):
-    assertEqual(str(resoudre(x)), y)
+    if not isinstance(y, (list, tuple, set)):
+        y = [y]
+    if not assertEqualAny(str(resoudre(x)), y, _raise=False):
+        print(_red('-> Test failed for %s' % repr(x)))
+        assert False
 
 def assert_positif(x, y):
-    assertEqual(unicode(positif(x)), y)
+    assertEqual(str(positif(x)), y)
 
 def assert_ens_def(x, y):
-    assertEqual(unicode(ensemble_definition(x)), y)
+    assertEqual(str(ensemble_definition(x)), y)
 
 def test_resoudre():
     assert_resoudre("2*x=0", "{0}")
-    assert_resoudre("2*x>0", u"]0;+oo[")
-    assert_resoudre("(x>4 et x<7) ou (x/2-1>=3)", u"]4;7[U[8;+oo[")
-    assert_resoudre("(2)*x>0", u"]0;+oo[")
-    assert_resoudre("2*x+3>5*x-4 et 3*x+1>=4*x-4", u']-oo;7/3[')
-    assert_resoudre("2*x+3*y=4 et 4*x-2*y=1", u"{x: 11/16, y: 7/8}")
+    assert_resoudre("2*x>0", "]0;+oo[")
+    assert_resoudre("(x>4 et x<7) ou (x/2-1>=3)", "]4;7[U[8;+oo[")
+    assert_resoudre("(2)*x>0", "]0;+oo[")
+    assert_resoudre("2*x+3>5*x-4 et 3*x+1>=4*x-4", ']-oo;7/3[')
+    assert_resoudre("2*x+3*y=4 et 4*x-2*y=1", ["{x: 11/16, y: 7/8}", "{y: 7/8, x: 11/16}"])
     assert_resoudre("ln(x)<ln(-2*x+1)", "]0;1/3[")
     assert_resoudre("exp(x^2)-x^2-1>=0", "]-oo;+oo[")
-    assert_resoudre(u"x*(sqrt(64-x^2))=32", "{4*sqrt(2)}")
+    assert_resoudre("x*(sqrt(64-x^2))=32", "{4*sqrt(2)}")
     assert_resoudre('x - 1 + exp(x)>=0', '[0;+oo[')
 
 def test_resoudre_abs():
@@ -52,7 +58,7 @@ def test_resoudre_substitution():
 def test_resoudre_puissances():
     assert_resoudre('sqrt(x)>4', ']16;+oo[')
     assert_resoudre('x^2.3>4', ']2^(20/23);+oo[')
-    assert_resoudre('-3*x^2.3>4', '{}')
+    assert_resoudre('-3*x^2.3>4', ['{}', 'Ø'])
 
 def test_sqrt():
     assert_resoudre('x+sqrt(x)>4', ']-sqrt(17)/2 + 9/2;+oo[')
@@ -65,9 +71,9 @@ def test_trigo():
 
 def test_resoudre_floats():
     # pass (Geophar 12.08 revision 64f4bb42)
-    assert_resoudre(u"0.5*exp(-0.5*x + 0.4)=0.5", "{4/5}")
+    assert_resoudre("0.5*exp(-0.5*x + 0.4)=0.5", "{4/5}")
     # fail (Geophar 12.08 revision 64f4bb42)
-    assert_resoudre(u"exp(-0.5*x - 0.4)-1=0", "{-4/5}")
+    assert_resoudre("exp(-0.5*x - 0.4)-1=0", "{-4/5}")
 
 def test_positif():
     x = Symbol("x")
@@ -98,3 +104,7 @@ def test_issue_306():
     assert_positif(x + sqrt(x**2 - 5), '[sqrt(5);+oo[')
     assert_positif(x - sqrt(x**2 - 5), '[sqrt(5);+oo[')
 
+def test_poly3():
+    sols = resoudre('5 + 1500/x**2 - 2*(1500*x + 100)/x**3=0', ensemble='R')
+    # 3 solutions
+    assert len(sols.intervalles) == 3
